@@ -576,7 +576,7 @@ protected:
 	std::string DiscoverLanguage();
 	void OpenCurrentFile(long long fileSize, bool suppressMessage, bool asynchronous);
 	virtual void OpenUriList(const char *) {}
-	virtual bool OpenDialog(const FilePath &directory, const GUI::gui_char *filesFilter) = 0;
+	virtual bool OpenDialog(const FilePath &directory, const GUI::gui_string &filesFilter) = 0;
 	virtual bool SaveAsDialog() = 0;
 	virtual void LoadSessionDialog() {}
 	virtual void SaveSessionDialog() {}
@@ -595,7 +595,7 @@ protected:
 	void PerformDeferredTasks();
 	enum class OpenCompletion { synchronous, completeCurrent, completeSwitch };
 	void CompleteOpen(OpenCompletion oc);
-	virtual bool PreOpenCheck(const GUI::gui_char *file);
+	virtual bool PreOpenCheck(const GUI::gui_string &file);
 	bool Open(const FilePath &file, OpenFlags of = ofNone);
 	bool OpenSelected();
 	void Revert();
@@ -653,7 +653,7 @@ protected:
 	SA::Span GetSelection();
 	SelectedRange GetSelectedRange();
 	void SetSelection(SA::Position anchor, SA::Position currentPos);
-	std::string GetCTag();
+	std::string GetCTag(GUI::ScintillaWindow *pw);
 	virtual std::string GetRangeInUIEncoding(GUI::ScintillaWindow &win, SA::Span span);
 	static std::string GetLine(GUI::ScintillaWindow &win, SA::Line line);
 	void RangeExtend(GUI::ScintillaWindow &wCurrent, SA::Span &range,
@@ -725,8 +725,8 @@ protected:
 	void GoMatchingBrace(bool select);
 	void GoMatchingPreprocCond(int direction, bool select);
 	virtual void FindReplace(bool replace) = 0;
-	void OutputAppendString(const char *s, SA::Position len = -1);
-	virtual void OutputAppendStringSynchronised(const char *s, SA::Position len = -1);
+	void OutputAppendString(std::string_view s);
+	virtual void OutputAppendStringSynchronised(std::string_view s);
 	virtual void Execute();
 	virtual void StopExecute() = 0;
 	void ShowMessages(SA::Line line);
@@ -763,8 +763,8 @@ protected:
 	SA::Line GetCurrentLineNumber();
 	SA::Position GetCurrentColumnNumber();
 	SA::Line GetCurrentScrollPosition();
-	virtual void AddCommand(const std::string &cmd, const std::string &dir,
-				JobSubsystem jobType, const std::string &input = "",
+	virtual void AddCommand(std::string_view cmd, std::string_view dir,
+				JobSubsystem jobType, std::string_view input = "",
 				int flags = 0);
 	virtual void AboutDialog() = 0;
 	virtual void QuitProgram() = 0;
@@ -874,9 +874,8 @@ protected:
 	void SetRepresentations();
 	virtual void ReadProperties();
 	void ReadEditorConfig(const std::string &fileNameForExtension);
-	std::string StyleString(const char *lang, int style) const;
 	StyleDefinition StyleDefinitionFor(int style);
-	void SetOneStyle(GUI::ScintillaWindow &win, int style, const StyleDefinition &sd);
+	void SetOneStyle(GUI::ScintillaWindow &win, int style, std::string_view definition);
 	void SetStyleBlock(GUI::ScintillaWindow &win, const char *lang, int start, int last);
 	void SetStyleFor(GUI::ScintillaWindow &win, const char *lang);
 	static void SetOneIndicator(GUI::ScintillaWindow &win, SA::IndicatorNumbers indicator, const IndicatorDefinition &ind);
@@ -899,7 +898,7 @@ protected:
 
 	void SetHomeProperties();
 	void UIAvailable();
-	void PerformOne(char *action);
+	void PerformOne(std::string_view action);
 	void StartRecordMacro();
 	void StopRecordMacro();
 	void StartPlayMacro();
@@ -908,7 +907,7 @@ protected:
 	void AskMacroList();
 	bool StartMacroList(const char *words);
 	void ContinueMacroList(const char *stext);
-	bool ProcessCommandLine(const GUI::gui_string &args, int phase);
+	bool ProcessCommandLine(const std::vector<GUI::gui_string> &args, int phase);
 	virtual bool IsStdinBlocked();
 	void OpenFromStdin(bool UseOutputPane);
 	void OpenFilesFromStdin();
@@ -920,7 +919,7 @@ protected:
 	void EnumProperties(const char *propkind);
 	void SendOneProperty(const char *kind, const char *key, const char *val);
 	void PropertyFromDirector(const char *arg);
-	void PropertyToDirector(const char *arg);
+	void PropertyToDirector(std::string_view arg);
 	// ExtensionAPI
 	intptr_t Send(Pane p, SA::Message msg, uintptr_t wParam = 0, intptr_t lParam = 0) override;
 	std::string Range(Pane p, SA::Span range) override;
