@@ -13,6 +13,7 @@
 #include <ctime>
 #include <clocale>
 
+#include <stdexcept>
 #include <tuple>
 #include <string>
 #include <string_view>
@@ -100,7 +101,7 @@ void SciTEBase::SetLanguageMenu() {
 	}
 	for (unsigned int item = 0; item < languageMenu.size(); item++) {
 		const int itemID = languageCmdID + item;
-		const GUI::gui_string entry = localiser.Text(languageMenu[item].menuItem.c_str());
+		const GUI::gui_string entry = localiser.Text(languageMenu[item].menuItem);
 		const GUI::gui_string menuKey = GUI::StringFromUTF8(languageMenu[item].menuKey);
 		if (entry.size() && entry[0] != '#') {
 			SetMenuItem(menuLanguage, item, itemID, entry.c_str(), menuKey.c_str());
@@ -258,6 +259,28 @@ void OptionalSetColour(GUI::ScintillaWindow &scintilla, SA::Element element, con
 	}
 }
 
+std::string Join(std::string_view prefix, std::string_view sv, std::string_view suffix) {
+	std::string ret(prefix);
+	ret += sv;
+	ret += suffix;
+	return ret;
+}
+
+constexpr std::string_view stylePrefix = "style.";
+
+std::string StyleName(std::string_view language, int style) {
+	std::string ret(stylePrefix);
+	ret += language;
+	ret += ".";
+	ret += std::to_string(style);
+	return ret;
+}
+
+std::string StyleName(std::string_view language, int style, int subStyle) {
+	std::string base = StyleName(language, style);
+	return base + "." + std::to_string(subStyle);
+}
+
 }
 
 void SciTEBase::SetElementColour(SA::Element element, const char *key) {
@@ -294,15 +317,9 @@ const char *SciTEBase::GetNextPropItem(
 	return pNext;
 }
 
-std::string SciTEBase::StyleString(const char *lang, int style) const {
-	char key[200];
-	sprintf(key, "style.%s.%0d", lang, style);
-	return props.GetExpandedString(key);
-}
-
 StyleDefinition SciTEBase::StyleDefinitionFor(int style) {
-	const std::string ssDefault = StyleString("*", style);
-	std::string ss = StyleString(language.c_str(), style);
+	const std::string ssDefault = props.GetExpandedString(StyleName("*", style));
+	std::string ss = props.GetExpandedString(StyleName(language, style));
 
 	if (!subStyleBases.empty()) {
 		const int baseStyle = wEditor.StyleFromSubStyle(style);
@@ -314,9 +331,8 @@ StyleDefinition SciTEBase::StyleDefinitionFor(int style) {
 			const int subStylesLength = wEditor.SubStylesLength(primaryBase);
 			const int subStyle = style - (subStylesStart + distanceSecondary);
 			if (subStyle < subStylesLength) {
-				char key[200];
-				sprintf(key, "style.%s.%0d.%0d", language.c_str(), baseStyle, subStyle + 1);
-				ss = props.GetNewExpandString(key);
+				const std::string key = StyleName(language, baseStyle, subStyle + 1);
+				ss = props.GetExpandedString(key);
 			}
 		}
 	}
@@ -326,7 +342,8 @@ StyleDefinition SciTEBase::StyleDefinitionFor(int style) {
 	return sd;
 }
 
-void SciTEBase::SetOneStyle(GUI::ScintillaWindow &win, int style, const StyleDefinition &sd) {
+void SciTEBase::SetOneStyle(GUI::ScintillaWindow &win, int style, std::string_view definition) {
+	const StyleDefinition sd(definition);
 	if (sd.specified & StyleDefinition::sdItalics)
 		win.StyleSetItalic(style, sd.italics);
 	if (sd.specified & StyleDefinition::sdWeight)
@@ -363,11 +380,10 @@ void SciTEBase::SetOneStyle(GUI::ScintillaWindow &win, int style, const StyleDef
 void SciTEBase::SetStyleBlock(GUI::ScintillaWindow &win, const char *lang, int start, int last) {
 	for (int style = start; style <= last; style++) {
 		if (style != StyleDefault) {
-			char key[200];
-			sprintf(key, "style.%s.%0d", lang, style-start);
+			const std::string key = StyleName(lang, style-start);
 			std::string sval = props.GetExpandedString(key);
 			if (sval.length()) {
-				SetOneStyle(win, style, StyleDefinition(sval));
+				SetOneStyle(win, style, sval);
 			}
 		}
 	}
@@ -387,17 +403,17 @@ void SciTEBase::SetOneIndicator(GUI::ScintillaWindow &win, SA::IndicatorNumbers
 }
 
 void SciTEBase::SetIndicatorFromProperty(GUI::ScintillaWindow &win, SA::IndicatorNumbers indicator, const std::string &propertyName) {
-	const std::string indicatorString = props.GetExpandedString(propertyName.c_str());
+	const std::string indicatorString = props.GetExpandedString(propertyName);
 	if (!indicatorString.empty()) {
-		IndicatorDefinition modifiedIndicator(indicatorString);
+		const IndicatorDefinition modifiedIndicator(indicatorString);
 		SetOneIndicator(win, indicator, modifiedIndicator);
 	}
 }
 
 void SciTEBase::SetMarkerFromProperty(GUI::ScintillaWindow &win, int marker, const std::string &propertyName) {
-	const std::string markerString = props.GetExpandedString(propertyName.c_str());
+	const std::string markerString = props.GetExpandedString(propertyName);
 	if (!markerString.empty()) {
-		MarkerDefinition markerValue(markerString);
+		const MarkerDefinition markerValue(markerString);
 		win.MarkerDefine(marker, markerValue.style);
 		win.MarkerSetForeTranslucent(marker, markerValue.colour);
 		win.MarkerSetBackTranslucent(marker, markerValue.back);
@@ -447,7 +463,7 @@ void SciTEBase::DefineMarker(SA::MarkerOutline marker, SA::MarkerSymbol markerTy
 
 void SciTEBase::ReadAPI(const std::string &fileNameForExtension) {
 	std::string sApiFileNames = props.GetNewExpandString("api.",
-				    fileNameForExtension.c_str());
+				    fileNameForExtension);
 	if (sApiFileNames.length() > 0) {
 		std::vector<std::string> vApiFileNames = StringSplit(sApiFileNames, ';');
 		std::vector<char> data;
@@ -468,7 +484,7 @@ void SciTEBase::ReadAPI(const std::string &fileNameForExtension) {
 std::string SciTEBase::FindLanguageProperty(const char *pattern, const char *defaultValue) {
 	std::string key = pattern;
 	Substitute(key, "*", language);
-	std::string ret = props.GetExpandedString(key.c_str());
+	std::string ret = props.GetExpandedString(key);
 	if (ret == "")
 		ret = props.GetExpandedString(pattern);
 	if (ret == "")
@@ -562,6 +578,11 @@ static const char *propertiesToForward[] = {
 	"lexer.as.comment.character",
 	"lexer.asm.comment.delimiter",
 	"lexer.baan.styling.within.preprocessor",
+	"lexer.bash.command.substitution",
+	"lexer.bash.styling.inside.backticks",
+	"lexer.bash.styling.inside.heredoc",
+	"lexer.bash.styling.inside.parameter",
+	"lexer.bash.styling.inside.string",
 	"lexer.caml.magic",
 	"lexer.cpp.allow.dollars",
 	"lexer.cpp.backquoted.strings",
@@ -619,6 +640,7 @@ static const char *propertiesToForward[] = {
 	"lexer.tex.comment.process",
 	"lexer.tex.interface.default",
 	"lexer.tex.use.keywords",
+	"lexer.vb.strings.multiline",
 	"lexer.verilog.allupperkeywords",
 	"lexer.verilog.fold.preprocessor.else",
 	"lexer.verilog.portstyling",
@@ -729,8 +751,8 @@ static const char *bookmarkBluegem[] = {
 std::string SciTEBase::GetFileNameProperty(const char *name) {
 	std::string namePlusDot = name;
 	namePlusDot.append(".");
-	std::string valueForFileName = props.GetNewExpandString(namePlusDot.c_str(),
-				       ExtensionFileName().c_str());
+	std::string valueForFileName = props.GetNewExpandString(namePlusDot,
+				       ExtensionFileName());
 	if (valueForFileName.length() != 0) {
 		return valueForFileName;
 	} else {
@@ -804,13 +826,13 @@ void SciTEBase::ReadProperties() {
 	for (std::string property : libraryProperties) {
 		std::string key("lexilla.context.");
 		key += property;
-		std::string value = props.GetExpandedString(key.c_str());
+		std::string value = props.GetExpandedString(key);
 		Lexilla::SetProperty(property.c_str(), value.c_str());
 	}
 
 	const std::string fileNameForExtension = ExtensionFileName();
 
-	language = props.GetNewExpandString("lexer.", fileNameForExtension.c_str());
+	language = props.GetNewExpandString("lexer.", fileNameForExtension);
 	if (language.empty()) {
 		language = "null";
 	}
@@ -837,14 +859,14 @@ void SciTEBase::ReadProperties() {
 		wOutput.SetILexer(plexerErrorlist);
 	}
 
-	const std::string kw0 = props.GetNewExpandString("keywords.", fileNameForExtension.c_str());
+	const std::string kw0 = props.GetNewExpandString("keywords.", fileNameForExtension);
 	wEditor.SetKeyWords(0, kw0.c_str());
 
 	for (int wl = 1; wl <= SA::KeywordsetMax; wl++) {
 		std::string kwk = StdStringFromInteger(wl+1);
 		kwk += '.';
 		kwk.insert(0, "keywords");
-		const std::string kw = props.GetNewExpandString(kwk.c_str(), fileNameForExtension.c_str());
+		const std::string kw = props.GetNewExpandString(kwk, fileNameForExtension);
 		wEditor.SetKeyWords(wl, kw.c_str());
 	}
 
@@ -859,8 +881,8 @@ void SciTEBase::ReadProperties() {
 			ssSubStylesKey += language;
 			ssSubStylesKey += ".";
 			ssSubStylesKey += sStyleBase;
-			std::string ssNumber = props.GetNewExpandString(ssSubStylesKey.c_str());
-			int subStyleIdentifiers = atoi(ssNumber.c_str());
+			std::string ssNumber = props.GetNewExpandString(ssSubStylesKey);
+			int subStyleIdentifiers = IntegerFromString(ssNumber, 0);
 
 			int subStyleIdentifiersStart = 0;
 			if (subStyleIdentifiers) {
@@ -875,7 +897,7 @@ void SciTEBase::ReadProperties() {
 				ssWordsKey += ".";
 				ssWordsKey += StdStringFromInteger(subStyle + 1);
 				ssWordsKey += ".";
-				std::string ssWords = props.GetNewExpandString(ssWordsKey.c_str(), fileNameForExtension.c_str());
+				std::string ssWords = props.GetNewExpandString(ssWordsKey, fileNameForExtension);
 				wEditor.SetIdentifiers(subStyleIdentifiersStart + subStyle, ssWords.c_str());
 			}
 		}
@@ -888,15 +910,15 @@ void SciTEBase::ReadProperties() {
 		ForwardPropertyToEditor(propertiesToForward[i]);
 	}
 
-	if (apisFileNames != props.GetNewExpandString("api.", fileNameForExtension.c_str())) {
+	if (apisFileNames != props.GetNewExpandString("api.", fileNameForExtension)) {
 		apis.Clear();
 		ReadAPI(fileNameForExtension);
-		apisFileNames = props.GetNewExpandString("api.", fileNameForExtension.c_str());
+		apisFileNames = props.GetNewExpandString("api.", fileNameForExtension);
 	}
 
 	props.Set("APIPath", apisFileNames);
 
-	FilePath fileAbbrev = GUI::StringFromUTF8(props.GetNewExpandString("abbreviations.", fileNameForExtension.c_str()));
+	FilePath fileAbbrev = GUI::StringFromUTF8(props.GetNewExpandString("abbreviations.", fileNameForExtension));
 	if (!fileAbbrev.IsSet())
 		fileAbbrev = GetAbbrevPropertiesFileName();
 	if (!pathAbbreviations.SameNameAs(fileAbbrev)) {
@@ -1002,8 +1024,9 @@ void SciTEBase::ReadProperties() {
 
 	const std::string caretPeriod = props.GetString("caret.period");
 	if (caretPeriod.length()) {
-		wEditor.SetCaretPeriod(atoi(caretPeriod.c_str()));
-		wOutput.SetCaretPeriod(atoi(caretPeriod.c_str()));
+		const int caretPeriodValue = IntegerFromString(caretPeriod, 0);
+		wEditor.SetCaretPeriod(caretPeriodValue);
+		wOutput.SetCaretPeriod(caretPeriodValue);
 	}
 
 	const int caretZoneX = props.GetInt("caret.policy.width", 50);
@@ -1110,11 +1133,8 @@ void SciTEBase::ReadProperties() {
 
 	CallChildren(SA::Message::SetWhitespaceSize, props.GetInt("whitespace.size", 1));
 
-	char bracesStyleKey[200];
-	sprintf(bracesStyleKey, "braces.%s.style", language.c_str());
-	bracesStyle = props.GetInt(bracesStyleKey, 0);
+	bracesStyle = props.GetInt(Join("braces.", language, ".style"), 0);
 
-	char key[200] = "";
 	std::string sval;
 
 	sval = FindLanguageProperty("calltip.*.ignorecase");
@@ -1130,21 +1150,21 @@ void SciTEBase::ReadProperties() {
 
 	calltipEndDefinition = FindLanguageProperty("calltip.*.end.definition");
 
-	sprintf(key, "autocomplete.%s.start.characters", language.c_str());
-	autoCompleteStartCharacters = props.GetExpandedString(key);
+	autoCompleteStartCharacters = props.GetExpandedString(
+		Join("autocomplete.", language, ".start.characters"));
 	if (autoCompleteStartCharacters == "")
 		autoCompleteStartCharacters = props.GetExpandedString("autocomplete.*.start.characters");
 	// "" is a quite reasonable value for this setting
 
-	sprintf(key, "autocomplete.%s.fillups", language.c_str());
-	autoCompleteFillUpCharacters = props.GetExpandedString(key);
+	autoCompleteFillUpCharacters = props.GetExpandedString(
+		Join("autocomplete.", language, ".fillups"));
 	if (autoCompleteFillUpCharacters == "")
 		autoCompleteFillUpCharacters =
 			props.GetExpandedString("autocomplete.*.fillups");
 	wEditor.AutoCSetFillUps(autoCompleteFillUpCharacters.c_str());
 
-	sprintf(key, "autocomplete.%s.typesep", language.c_str());
-	autoCompleteTypeSeparator = props.GetExpandedString(key);
+	autoCompleteTypeSeparator = props.GetExpandedString(
+		Join("autocomplete.", language, ".typesep"));
 	if (autoCompleteTypeSeparator == "")
 		autoCompleteTypeSeparator =
 			props.GetExpandedString("autocomplete.*.typesep");
@@ -1153,13 +1173,8 @@ void SciTEBase::ReadProperties() {
 			static_cast<unsigned char>(autoCompleteTypeSeparator[0]));
 	}
 
-	sprintf(key, "autocomplete.%s.ignorecase", "*");
-	sval = props.GetNewExpandString(key);
+	sval = FindLanguageProperty("autocomplete.*.ignorecase");
 	autoCompleteIgnoreCase = sval == "1";
-	sprintf(key, "autocomplete.%s.ignorecase", language.c_str());
-	sval = props.GetNewExpandString(key);
-	if (sval != "")
-		autoCompleteIgnoreCase = sval == "1";
 	wEditor.AutoCSetIgnoreCase(autoCompleteIgnoreCase);
 	wOutput.AutoCSetIgnoreCase(true);
 	autoCompleteVisibleItemCount = props.GetInt("autocomplete.visible.item.count", 9);
@@ -1201,9 +1216,7 @@ void SciTEBase::ReadProperties() {
 	wEditor.SetMarginWidthN(1, margin ? marginWidth : 0);
 
 	const std::string lineMarginProp = props.GetString("line.margin.width");
-	lineNumbersWidth = atoi(lineMarginProp.c_str());
-	if (lineNumbersWidth == 0)
-		lineNumbersWidth = lineNumbersWidthDefault;
+	lineNumbersWidth = IntegerFromString(lineMarginProp, lineNumbersWidthDefault);
 	lineNumbersExpand = lineMarginProp.find('+') != std::string::npos;
 
 	SetLineNumberWidth();
@@ -1228,20 +1241,20 @@ void SciTEBase::ReadProperties() {
 	bracesSloppy = props.GetInt("braces.sloppy");
 
 	wEditor.SetCharsDefault();
-	wordCharacters = props.GetNewExpandString("word.characters.", fileNameForExtension.c_str());
+	wordCharacters = props.GetNewExpandString("word.characters.", fileNameForExtension);
 	if (wordCharacters.length()) {
 		wEditor.SetWordChars(wordCharacters.c_str());
 	} else {
 		wordCharacters = "_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
 	}
 
-	whitespaceCharacters = props.GetNewExpandString("whitespace.characters.", fileNameForExtension.c_str());
+	whitespaceCharacters = props.GetNewExpandString("whitespace.characters.", fileNameForExtension);
 	if (whitespaceCharacters.length()) {
 		wEditor.SetWhitespaceChars(whitespaceCharacters.c_str());
 	}
 
 	const std::string viewIndentExamine = GetFileNameProperty("view.indentation.examine");
-	indentExamine = viewIndentExamine.length() ? static_cast<SA::IndentView>(atoi(viewIndentExamine.c_str())) : SA::IndentView::Real;
+	indentExamine = static_cast<SA::IndentView>(IntegerFromString(viewIndentExamine, 1));
 	wEditor.SetIndentationGuides(props.GetInt("view.indentation.guides") ?
 				     indentExamine : SA::IndentView::None);
 
@@ -1250,21 +1263,18 @@ void SciTEBase::ReadProperties() {
 
 	wEditor.CallTipUseStyle(32);
 
-	std::string useStripTrailingSpaces = props.GetNewExpandString("strip.trailing.spaces.", ExtensionFileName().c_str());
-	if (useStripTrailingSpaces.length() > 0) {
-		stripTrailingSpaces = atoi(useStripTrailingSpaces.c_str()) != 0;
-	} else {
-		stripTrailingSpaces = props.GetInt("strip.trailing.spaces") != 0;
-	}
+	std::string useStripTrailingSpaces = props.GetNewExpandString("strip.trailing.spaces.", ExtensionFileName());
+	stripTrailingSpaces = IntegerFromString(useStripTrailingSpaces, props.GetInt("strip.trailing.spaces")) != 0;
+
 	ensureFinalLineEnd = props.GetInt("ensure.final.line.end") != 0;
 	ensureConsistentLineEnds = props.GetInt("ensure.consistent.line.ends") != 0;
 
 	indentOpening = props.GetInt("indent.opening");
 	indentClosing = props.GetInt("indent.closing");
-	indentMaintain = atoi(props.GetNewExpandString("indent.maintain.", fileNameForExtension.c_str()).c_str());
+	indentMaintain = IntegerFromString(props.GetNewExpandString("indent.maintain.", fileNameForExtension), 0);
 
-	const std::string lookback = props.GetNewExpandString("statement.lookback.", fileNameForExtension.c_str());
-	statementLookback = atoi(lookback.c_str());
+	const std::string lookback = props.GetNewExpandString("statement.lookback.", fileNameForExtension);
+	statementLookback = IntegerFromString(lookback, 0);
 	statementIndent = GetStyleAndWords("statement.indent.");
 	statementEnd = GetStyleAndWords("statement.end.");
 	blockStart = GetStyleAndWords("block.start.");
@@ -1279,11 +1289,11 @@ void SciTEBase::ReadProperties() {
 		{"preprocessor.middle.", PreProc::Middle},
 		{"preprocessor.end.", PreProc::End},
 	};
-	const std::string ppSymbol = props.GetNewExpandString("preprocessor.symbol.", fileNameForExtension.c_str());
+	const std::string ppSymbol = props.GetNewExpandString("preprocessor.symbol.", fileNameForExtension);
 	preprocessorSymbol = ppSymbol.empty() ? 0 : ppSymbol[0];
 	preprocOfString.clear();
 	for (const PropToPPC &preproc : propToPPC) {
-		const std::string list = props.GetNewExpandString(preproc.propName, fileNameForExtension.c_str());
+		const std::string list = props.GetNewExpandString(preproc.propName, fileNameForExtension);
 		const std::vector<std::string> words = StringSplit(list, ' ');
 		for (const std::string &word : words) {
 			preprocOfString[word] = preproc.ppc;
@@ -1426,10 +1436,10 @@ void SciTEBase::ReadProperties() {
 
 	const int foldStrokeWidth = props.GetInt("fold.stroke.width", 100);
 	// Isolated and connected fold markers use foreground and background colours differently
-	MarkerAppearance isolated {
+	const MarkerAppearance isolated {
 		colourFoldFore, colourFoldBack, colourFoldBlockHighlight, foldStrokeWidth
 	};
-	MarkerAppearance connected {
+	const MarkerAppearance connected {
 		colourFoldBack, colourFoldFore, colourFoldBlockHighlight, foldStrokeWidth
 	};
 	switch (foldSymbols) {
@@ -1531,7 +1541,7 @@ void SciTEBase::ReadProperties() {
 	currentWordHighlight.isEnabled = props.GetInt("highlight.current.word", 0) == 1;
 	if (currentWordHighlight.isEnabled) {
 		const std::string highlightCurrentWordIndicatorString = props.GetExpandedString("highlight.current.word.indicator");
-		IndicatorDefinition highlightCurrentWordIndicator(highlightCurrentWordIndicatorString.c_str());
+		IndicatorDefinition highlightCurrentWordIndicator(highlightCurrentWordIndicatorString);
 		if (highlightCurrentWordIndicatorString.length() == 0) {
 			highlightCurrentWordIndicator.style = SA::IndicatorStyle::RoundBox;
 			std::string highlightCurrentWordColourString = props.GetExpandedString("highlight.current.word.colour");
@@ -1573,7 +1583,7 @@ void SciTEBase::ReadProperties() {
 
 		// Check for an extension script
 		GUI::gui_string extensionFile = GUI::StringFromUTF8(
-							props.GetNewExpandString("extension.", fileNameForExtension.c_str()));
+							props.GetNewExpandString("extension.", fileNameForExtension));
 		if (extensionFile.length()) {
 			// find file in local directory
 			FilePath docDir = filePath.Directory();
@@ -1663,7 +1673,7 @@ void SciTEBase::ReadEditorConfig(const std::string &fileNameForExtension) {
 			diagnostic += "=";
 			diagnostic += pss.second;
 			diagnostic += "'.\n";
-			OutputAppendString(diagnostic.c_str());
+			OutputAppendString(diagnostic);
 			SetOutputVisibility(true);
 		}
 	}
@@ -1689,13 +1699,12 @@ void SetScintilluaStyles(GUI::ScintillaWindow &wEditor, PropSetFile& props, cons
 		do {
 			end = name.find('.', ++end);
 			char propStr[128] = "";
-			sprintf(propStr, "$(scintillua.styles.%s),", end == std::string::npos ?
+			snprintf(propStr, std::size(propStr), "$(scintillua.styles.%s),", end == std::string::npos ?
 				name.c_str() : name.substr(0, end).c_str());
 			finalPropStr += propStr;
 		} while (end != std::string::npos);
-		char key[256] = "";
-		sprintf(key, "style.%s.%0d", languageName, style);
-		props.Set(key, finalPropStr.c_str());
+		const std::string key = StyleName(languageName, style);
+		props.Set(key, finalPropStr);
 	};
 	const int namedStyles = wEditor.NamedStyles(); // this count includes predefined styles
 	constexpr int LastPredefined = static_cast<int>(Scintilla::StylesCommon::LastPredefined);
@@ -1717,7 +1726,6 @@ void SciTEBase::ReadFontProperties() {
 	const std::string monospaceFonts = props.GetExpandedString("font.monospaced.list");
 	monospacedList = StringSplit(monospaceFonts, ';');
 
-	char key[200] = "";
 	const char *languageName = language.c_str();
 
 	if (StartsWith(languageName, "scintillua.") && language.length() < 240) {
@@ -1740,14 +1748,12 @@ void SciTEBase::ReadFontProperties() {
 		wOutput.SetFontLocale(fontLocale.c_str());
 	}
 
-	sprintf(key, "style.%s.%0d", "*", StyleDefault);
-	std::string sval = props.GetNewExpandString(key);
-	SetOneStyle(wEditor, StyleDefault, StyleDefinition(sval));
-	SetOneStyle(wOutput, StyleDefault, StyleDefinition(sval));
+	std::string sval = props.GetExpandedString(StyleName("*", StyleDefault));
+	SetOneStyle(wEditor, StyleDefault, sval);
+	SetOneStyle(wOutput, StyleDefault, sval);
 
-	sprintf(key, "style.%s.%0d", languageName, StyleDefault);
-	sval = props.GetNewExpandString(key);
-	SetOneStyle(wEditor, StyleDefault, StyleDefinition(sval));
+	sval = props.GetExpandedString(StyleName(languageName, StyleDefault));
+	SetOneStyle(wEditor, StyleDefault, sval);
 
 	wEditor.StyleClearAll();
 
@@ -1766,9 +1772,9 @@ void SciTEBase::ReadFontProperties() {
 		for (int subStyle=0; subStyle<subStylesLength; subStyle++) {
 			for (int active=0; active<(diffToSecondary?2:1); active++) {
 				const int activity = active * diffToSecondary;
-				sprintf(key, "style.%s.%0d.%0d", languageName, subStyleBase + activity, subStyle+1);
-				sval = props.GetNewExpandString(key);
-				SetOneStyle(wEditor, subStylesStart + subStyle + activity, StyleDefinition(sval));
+				sval = props.GetExpandedString(
+					StyleName(language, subStyleBase + activity, subStyle + 1));
+				SetOneStyle(wEditor, subStylesStart + subStyle + activity, sval);
 			}
 		}
 	}
@@ -1779,9 +1785,8 @@ void SciTEBase::ReadFontProperties() {
 
 	wOutput.StyleClearAll();
 
-	sprintf(key, "style.%s.%0d", "errorlist", StyleDefault);
-	sval = props.GetNewExpandString(key);
-	SetOneStyle(wOutput, StyleDefault, StyleDefinition(sval));
+	sval = props.GetExpandedString(StyleName("errorlist", StyleDefault));
+	SetOneStyle(wOutput, StyleDefault, sval);
 
 	wOutput.StyleClearAll();
 
@@ -1790,7 +1795,7 @@ void SciTEBase::ReadFontProperties() {
 
 	if (CurrentBuffer()->useMonoFont) {
 		sval = props.GetExpandedString("font.monospace");
-		StyleDefinition sd(sval.c_str());
+		StyleDefinition sd(sval);
 		for (int style = 0; style <= StyleMax; style++) {
 			if (style != static_cast<int>(SA::StylesCommon::LineNumber)) {
 				if (sd.specified & StyleDefinition::sdFont) {
@@ -1836,7 +1841,7 @@ GUI::gui_string Localization::Text(std::string_view sv, bool retainIfNotFound) c
 	const int accessKeyPresent = Remove(translation, menuAccessIndicatorChar);
 	LowerCaseAZ(translation);
 	Substitute(translation, "\n", "\\n");
-	translation = GetString(translation.c_str());
+	translation = GetString(translation);
 	if (translation.length()) {
 		if (ellipseIndicator)
 			translation += sEllipse;
@@ -2041,5 +2046,5 @@ int SciTEBase::GetMenuCommandAsInt(const std::string &commandName) {
 	}
 
 	// Otherwise we might have entered a number as command to access a "SCI_" command
-	return atoi(commandName.c_str());
+	return IntegerFromString(commandName, 0);
 }
