@@ -19,7 +19,7 @@ extern void Platform_Initialise(void *hInstance) noexcept;
 extern void Platform_Finalise(bool fromDllMain) noexcept;
 
 constexpr RECT RectFromPRectangle(PRectangle prc) noexcept {
-	RECT rc = { static_cast<LONG>(prc.left), static_cast<LONG>(prc.top),
+	const RECT rc = { static_cast<LONG>(prc.left), static_cast<LONG>(prc.top),
 		static_cast<LONG>(prc.right), static_cast<LONG>(prc.bottom) };
 	return rc;
 }
